Name:		neon
Version:	0.30.2
Release: 	10
Summary:	An HTTP and WebDAV client library
License:	LGPLv2+
URL:		http://www.webdav.org/neon/
Source0:	http://www.webdav.org/neon/neon-%{version}.tar.gz

# These patches are from fedora: https://src.fedoraproject.org/rpms/neon/tree/f29
Patch0:		neon-0.27.0-multilib.patch
Patch1:		neon-0.30.2-sysuioh.patch
Patch2:		neon-0.30.2-lockprintf.patch

BuildRequires:  gcc git openssl-devel expat-devel gdb-headless
Requires:	ca-certificates

%description
neon is an HTTP and WebDAV client library, with a C interface. Features:\
* High-level wrappers for common HTTP and WebDAV operations (GET, MOVE, DELETE, etc)\
Low-level interface to the HTTP request/response engine, allowing the use of arbitrary\
HTTP methods, headers, etc.\
* Authentication support including Basic and Digest support, along with GSSAPI-based\
 Negotiate on Unix, and SSPI-based Negotiate/NTLM on Win32\
* SSL/TLS support using OpenSSL or GnuTLS; exposing an abstraction layer for verifying server\
certificates, handling client certificates, and examining certificate properties.\
Smartcard-based client certificates are also supported via a PKCS#11 wrapper interface.\
* Abstract interface to parsing XML using libxml2 or expat, and wrappers for simplifying\
handling XML HTTP response bodies\
* WebDAV metadata support; wrappers for PROPFIND and PROPPATCH to simplify property\
manipulation.\


%package devel
Summary:	Development files for %{name}
Requires:	neon = %{version}-%{release}, openssl-devel, zlib-devel, expat-devel
Requires:	pkgconfig
License:	LGPLv2+ and GPLv2+

%description devel
Libraries and header files of %{name} are all in the %{name}-devel package.

%package        help
Summary:        Help manual for %{name}

%description    help
The %{name}-help package conatins man manual etc

%prep
%autosetup -n %{name}-%{version} -p1 -Sgit
sed -ibak '/^install-docs/s/install-html//' Makefile.in

%build
export CC="%{__cc} -pthread"
%configure --with-expat --enable-shared --disable-static \
        --enable-warnings \
        --with-ssl=openssl --enable-threadsafe-ssl=posix \
        --with-libproxy
%make_build

%install
rm -rf $RPM_BUILD_ROOT
%make_install INSTALL="install -p"

sed -ri "/^dependency_libs/{s,-l[^ ']*,,g}" \
      $RPM_BUILD_ROOT%{_libdir}/libneon.la

%find_lang %{name}

%files -f %{name}.lang
%doc BUGS TODO NEWS README THANKS
%license AUTHORS src/COPYING.LIB
%{_libdir}/*.so.*

%files devel
%{_bindir}/*
%{_includedir}/*
%{_libdir}/pkgconfig/neon.pc
%{_libdir}/*.*a
%{_libdir}/*.so

%files help
%{_mandir}/man1/*
%{_mandir}/man3/*

%changelog
* Web 02 Jun 2021 zhaoyao<zhaoyao32@huawei.com> - 0.30.2-10
- fixs faileds: /bin/sh: gcc: command not found.

* Wed Nov 13 2019 openEuler Buildteam <buildteam@openeuler.org> - 0.30.2-9
- Package init
